@@ -79,10 +79,10 @@ def get_models():
             if name != '__init__' and ext.startswith('.py'):
                 filenames.add(name)
 
-    functions_path = pkg_resources.resource_filename('nexpy.api.frills', 
+    models_path = pkg_resources.resource_filename('nexpy.api.frills', 
                                                      'models')
-    sys.path.append(functions_path)
-    for file_ in os.listdir(functions_path):
+    sys.path.append(models_path)
+    for file_ in os.listdir(models_path):
         name, ext = os.path.splitext(file_)
         if name != '__init__' and ext.startswith('.py'):
             filenames.add(name)
@@ -91,19 +91,15 @@ def get_models():
     for name in sorted(filenames):
         try:
             module = importlib.import_module(name)
-            models.update(dict((n, m) 
+            models.update(dict((n.strip('Model'), m) 
                 for n, m in inspect.getmembers(module, inspect.isclass) 
                 if issubclass(m, Model) and n != 'Model'))
         except ImportError:
             pass
-    from lmfit import models as lmfit_models
-    models.update(dict((n, m) 
-                  for n, m in inspect.getmembers(lmfit_models, inspect.isclass) 
-                  if issubclass(m, Model) and n != 'Model'))
-
-    for model in ['DonaichModel', 'ExpressionModel']:
-        if model in models:
-            del models[model]
+    from lmfit.models import lmfit_models
+    models.update(lmfit_models)
+    del models['Expression']
+    del models['Gaussian-2D']
 
     return models
 
@@ -135,6 +131,8 @@ all_methods = get_methods()
 
 class NXModel(Model):
 
+    valid_forms = ()
+
     def __init__(self, module, **kwargs):
         self.module = module
         super(NXModel, self).__init__(self.module.values,
@@ -180,19 +178,20 @@ class FitDialog(NXPanel):
         self.setMinimumWidth(850)        
         self.tab_class = FitTab
 
-    def activate(self, data, plotview=None, color='C0'):
+    def activate(self, data, xmin=None, xmax=None, plotview=None, color='C0'):
         if plotview:
             label = plotview.label + ': ' + str(plotview.num) 
         else:
             label = data.nxroot.nxname + data.nxpath
-        super(FitDialog, self).activate(label, data, plotview=plotview, 
-                                        color=color)
+        super(FitDialog, self).activate(label, data, xmin=xmin, xmax=xmax,
+                                        plotview=plotview, color=color)
 
 
 class FitTab(NXTab):
     """Dialog to fit one-dimensional NeXus data"""
  
-    def __init__(self, label, data, plotview=None, color='C0', parent=None):
+    def __init__(self, label, data, xmin=None, xmax=None, 
+                 plotview=None, color='C0', parent=None):
 
         super(FitTab, self).__init__(label, parent=parent)
  
@@ -218,9 +217,11 @@ class FitTab(NXTab):
 
         self.initialize_models()
  
-        self.modelcombo = NXComboBox(items=list(self.all_models))
-        if 'GaussianModel' in self.modelcombo:
-            self.modelcombo.select('GaussianModel')
+        add_button = NXPushButton("Add Model", self.add_model)
+        self.modelcombo = NXComboBox(items=list(self.all_models), 
+                                     slot=self.choose_model)
+        if 'Gaussian' in self.modelcombo:
+            self.modelcombo.select('Gaussian')
         try:
             from pylatexenc.latex2text import LatexNodes2Text
             text = LatexNodes2Text().latex_to_text
@@ -233,9 +234,10 @@ class FitTab(NXTab):
                 tooltip = re.sub(r'\:[a-z]*\:', r'', tooltip)
                 self.modelcombo.setItemData(i, text(tooltip), 
                                             QtCore.Qt.ToolTipRole)
-        add_button = NXPushButton("Add Model", self.add_model)
-        model_layout = self.make_layout(self.modelcombo, add_button, 
-                                        align='left')
+        self.formcombo = NXComboBox()
+        self.formcombo.setVisible(False)
+        model_layout = self.make_layout(add_button, self.modelcombo, 
+                                        self.formcombo, align='left')
         
         self.parameter_layout = self.initialize_parameter_grid()
 
@@ -256,8 +258,14 @@ class FitTab(NXTab):
         self.plotcombo = NXComboBox()
         self.plotcombo.setVisible(False)
         plot_label = NXLabel('X:')
-        self.plot_min = self._data.nxaxes[0].min()
-        self.plot_max = self._data.nxaxes[0].max() 
+        if xmin:
+            self.plot_min = xmin
+        else:
+            self.plot_min = self._data.nxaxes[0].min()
+        if xmax:
+            self.plot_max = xmax
+        else:
+            self.plot_max = self._data.nxaxes[0].max() 
         self.plot_minbox = NXLineEdit(format_float(self.plot_min), 
                                       align='right', width=100)
         plot_tolabel = NXLabel(' to ')
@@ -329,7 +337,8 @@ class FitTab(NXTab):
             for shortcut in 'lr':
                 if shortcut in mpl.rcParams[key]:
                     mpl.rcParams[key].remove(shortcut)
-        self.fitview.canvas.mpl_connect('key_press_event', self.on_key_press)
+        self.cid = self.fitview.canvas.mpl_connect('key_press_event', 
+                                                   self.on_key_press)
 
     def __repr__(self):
         return 'FitTab("%s")' % self.data_label
@@ -337,12 +346,12 @@ class FitTab(NXTab):
     @property
     def fitview(self):
         if self.plotview and self.plotview.label in self.plotviews:
-            self._fitview = self.plotview
+            _fitview = self.plotview
         elif 'Fit' in self.plotviews:
-            self._fitview = self.plotviews['Fit']
+            _fitview = self.plotviews['Fit']
         else:
-            self._fitview = NXPlotView('Fit')
-        return self._fitview
+            _fitview = NXPlotView('Fit')
+        return _fitview
 
     def initialize_data(self, data):
         if isinstance(data, NXdata):
@@ -471,14 +480,22 @@ class FitTab(NXTab):
         return self.color_box.textbox.text()
 
     def compressed_name(self, name):
-        return re.sub(r'([a-zA-Z]*) # (\d*) ', r'\1\2', name, count=1)
+        return re.sub(r'([a-zA-Z_ ]*) [#] (\d*) $', r'\1_\2', 
+                      name, count=1).replace(' ', '_')
 
     def expanded_name(self, name):
-        return re.sub(r'([a-zA-Z]*)(\d*)', r'\1 # \2 ', name, count=1)
-    
+        return re.sub(r'([a-zA-Z_]*)_(\d*)$', r'\1 # \2 ', 
+                      name, count=1).replace('_', ' ')
+
     def parse_model_name(self, name):
-        match = re.match(r'([a-zA-Z]*)(\d*)', name)
-        return match.group(1), match.group(2)
+        match = re.match(r'([a-zA-Z0-9_-]*)_(\d*)$', name)
+        if match:
+            return match.group(1).replace('_', ' '), match.group(2)
+        try:
+            match = re.match(r'([a-zA-Z]*)(\d*)', name)
+            return match.group(1), match.group(2)
+        except Exception as error:
+            return None, None
 
     def load_group(self, group):
         self.model = None
@@ -490,7 +507,7 @@ class FitTab(NXTab):
                     model_class = group[model_name]['parameters'].attrs['model']
                 else:
                     model_class, model_index = self.parse_model_name(model_name)
-                    if (model_class not in self.all_models and 
+                    if (model_class and model_class not in self.all_models and 
                         model_class+'Model' in self.all_models):
                         model_class = model_class + 'Model'          
                 if model_class in self.all_models:
@@ -549,16 +566,29 @@ class FitTab(NXTab):
     def get_model_instance(self, model_class, prefix=None):
         if isinstance(self.all_models[model_class], types.ModuleType):
             return NXModel(self.all_models[model_class], prefix=prefix)
+        elif self.all_models[model_class].valid_forms:
+            return self.all_models[model_class](prefix=prefix,
+                                                form=self.formcombo.selected)
         else:
-            if model_class == 'PolynomialModel':
-                return self.all_models[model_class](7, prefix=prefix)
+            return self.all_models[model_class](prefix=prefix)
+
+    def choose_model(self):
+        model_class = self.modelcombo.selected
+        try:
+            if self.all_models[model_class].valid_forms:
+                self.formcombo.setVisible(True)
+                self.formcombo.clear()
+                self.formcombo.add(*self.all_models[model_class].valid_forms)
             else:
-                return self.all_models[model_class](prefix=prefix)
+                self.formcombo.setVisible(False)
+        except AttributeError:
+            self.formcombo.setVisible()
                
     def add_model(self):
         model_class = self.modelcombo.selected
         model_index = len(self.models)
-        model_name = model_class.replace('Model', '') + str(model_index+1)
+        model_name = (model_class.replace('Model', '').replace(' ', '_') 
+                      + '_' + str(model_index+1))
         model = self.get_model_instance(model_class, prefix=model_name)
         try:
             if self.model:
@@ -743,13 +773,17 @@ class FitTab(NXTab):
         return float(self.plot_minbox.text()), float(self.plot_maxbox.text())
 
     def reset_limits(self):
+        self.plot_min = self.fitview.xaxis.lo
+        self.plot_max = self.fitview.xaxis.hi
         self.plot_minbox.setText(format_float(self.plot_min))
         self.plot_maxbox.setText(format_float(self.plot_max))
-        self.fitview.reset_plot_limits()
+        self.fitview.set_plot_limits(xmin=self.plot_min, xmax=self.plot_max)
 
     def plot_data(self):
         if self.plotview is None:
-            self.fitview.plot(self._data, fmt='o', color=self.color)
+            self.fitview.plot(self._data, 
+                              xmin=self.plot_min, xmax=self.plot_max,
+                              color=self.color)
             self.fitview.set_plot_limits(*self.get_limits())
             for label in ['label', 'legend_label']:
                 self.fitview.plots[self.fitview.num][label] = self.data_label
@@ -771,17 +805,20 @@ class FitTab(NXTab):
                 fmt = '-'
             else:
                 fmt = '--'
-            self.fitview.plot(self.get_model(), fmt=fmt, over=True, num=num,
-                              color=self.color)
+            self.fitview.plot(self.get_model(), fmt=fmt, 
+                              xmin=self.plot_min, xmax=self.plot_max,
+                              over=True, num=num, color=self.color)
             if self.fitted:
                 self.fitview.plots[num]['legend_label'] = 'Fit'
             else:
                 self.fitview.plots[num]['legend_label'] = 'Model'
         else:
             name = self.compressed_name(model_name)
-            self.fitview.plot(self.get_model(name), fmt='--', over=True, 
-                              num=num)
+            self.fitview.plot(self.get_model(name), fmt='--', 
+                              xmin=self.plot_min, xmax=self.plot_max,
+                              over=True, num=num)
             self.fitview.plots[num]['legend_label'] = name
+        self.fitview.set_plot_limits(xmin=self.plot_min, xmax=self.plot_max)
         self.plot_nums.append(num)
         self.fitview.ytab.plotcombo.select(self.data_num)
         self.fitview.raise_()
@@ -921,5 +958,6 @@ class FitTab(NXTab):
         self.plot_data()
 
     def close(self):
+        self.fitview.canvas.mpl_disconnect(self.cid)
         if self.plotview:
             self.remove_plots()
