@@ -11,7 +11,7 @@
 #-----------------------------------------------------------------------------
 
 pkg_requirements = [
-    'nexusformat>=0.6.0',
+    'nexusformat>=0.6.1',
     'numpy',
     'scipy',
     'h5py',
@@ -20,7 +20,7 @@ pkg_requirements = [
     'qtconsole',
     'ipython',
     'matplotlib',
-    'lmfit',
+    'lmfit>=1.0.2',
     'pylatexenc',
     'ansi2html',
     'pillow'
